#!/bin/bash
# packager          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# package	    : syslinux
# homepage	    : http://syslinux.zytor.com/
# source location   : http://www.kernel.org/pub/linux/utils/boot/syslinux/syslinux-4.05.tar.bz2
# dependency        : 

set -e -u -x

softname='syslinux'
softversion='4.05'
packageversion='72.1'

arch='i486'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.bz2"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://www.kernel.org/pub/linux/utils/boot/syslinux/$softname-$softversion.tar.bz2

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
        |-----handy-ruler------------------------------------------------------|
syslinux: syslinux (SYSLINUX/PXELINUX/ISOLINUX boot loaders)
syslinux:
syslinux: SYSLINUX is a boot loader for the Linux operating system which
syslinux: operates off an MS-DOS/Windows FAT filesystem.  This is used by the
syslinux: Slackware makebootdisk script to create system boot floppies.
syslinux:
syslinux: Also included are PXELINUX and ISOLINUX, boot loaders for booting from
syslinux: a network server or CD-ROM.
syslinux:
syslinux: SYSLINUX, PXELINUX, and ISOLINUX were written by H. Peter Anvin.
syslinux:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src	

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

# Do not try to build syslinux with our default LDFLAGS, it will fail
unset LDFLAGS

patch -p1 < ../syslinux-dont-build-dos-windows-targets.patch

make || exit 1
make SBINDIR=$dest/sbin BINDIR=$dest/usr/bin INCDIR=$dest/usr/include MANDIR=$dest/usr/man AUXDIR=$dest/usr/lib/syslinux install

mkdir -p $dest/usr/include
cp -a libinstaller/syslinux.h $dest/usr/include

rm -rf $dest/usr/lib/syslinux/com32
  
# add 'default' files
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      COPYING NEWS README* doc/*.txt \
      com32/LICENCE \
      $dest/usr/doc/$softname-$softversion
	
# strip executables
( cd $dest
find $dest | xargs -r file | grep "executable\|shared object" | grep ELF |\
	cut -f 1 -d : | xargs -r strip --strip-unneeded
find $dest | xargs -r file | grep "current ar archive" |\
	cut -f 1 -d : | xargs -r strip -g
)

# compress man page
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# Buildscript
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion
cp syslinux-dont-build-dos-windows-targets.patch $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/a/syslinux/source/build-syslinux.sh > $package.src
echo $source >> $package.src

# erase source
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
